type token =
  | IDENTIFIER of (string)
  | CONSTANT of (Jc_ast.const)
  | STRING_LITERAL of (string)
  | LPAR
  | RPAR
  | LBRACE
  | RBRACE
  | LSQUARE
  | RSQUARE
  | DOTDOT
  | SEMICOLON
  | COMMA
  | COLON
  | DOT
  | QUESTION
  | MINUS
  | MINUSMINUS
  | PLUS
  | PLUSPLUS
  | STAR
  | SLASH
  | PERCENT
  | EQ
  | LTEQ
  | GTEQ
  | GT
  | LT
  | EQEQ
  | BANGEQ
  | LTCOLON
  | COLONGT
  | PLUSEQ
  | MINUSEQ
  | STAREQ
  | SLASHEQ
  | PERCENTEQ
  | AMPAMP
  | BARBAR
  | EQGT
  | LTEQGT
  | EXCLAM
  | IF
  | ELSE
  | RETURN
  | WHILE
  | PACK
  | UNPACK
  | TYPE
  | INVARIANT
  | WITH
  | VARIANT
  | INTEGER
  | BOOLEAN
  | REAL
  | UNIT
  | ASSIGNS
  | ASSUMES
  | BEHAVIOR
  | ENSURES
  | REQUIRES
  | BSFORALL
  | BSOFFSET_MAX
  | BSOFFSET_MIN
  | BSOLD
  | BSRESULT
  | AXIOM
  | EOF

open Parsing;;
# 28 "jc/jc_parser.mly"

  open Format
  open Jc_env
  open Jc_ast
  open Parsing
  open Error

  let loc () = (symbol_start_pos (), symbol_end_pos ())
  let loc_i i = (rhs_start_pos i, rhs_end_pos i)

  let locate_type e =
    { jc_ptype_node = e ; jc_ptype_loc = loc () }

  let locate_expr e =
    { jc_pexpr_node = e ; jc_pexpr_loc = loc () }

  let locate_statement s =
    { jc_pstatement_node = s ; jc_pstatement_loc = loc () }

  let locate_decl d =
    { jc_pdecl_node = d ; jc_pdecl_loc = loc () }

  let int_of_constant loc c =
    try
      match c with
	| JCCinteger n -> int_of_string n
	| _ -> invalid_arg ""
    with
	Invalid_argument _ ->
	  Jc_options.parsing_error loc "invalid integer constant"

(*
  let locate x = { node = x; loc = loc() }
  let locate_i i x = { node = x; loc = loc_i i }
  let with_loc l x = { node = x; loc = l }
*)


# 111 "jc/jc_parser.ml"
let yytransl_const = [|
  260 (* LPAR *);
  261 (* RPAR *);
  262 (* LBRACE *);
  263 (* RBRACE *);
  264 (* LSQUARE *);
  265 (* RSQUARE *);
  266 (* DOTDOT *);
  267 (* SEMICOLON *);
  268 (* COMMA *);
  269 (* COLON *);
  270 (* DOT *);
  271 (* QUESTION *);
  272 (* MINUS *);
  273 (* MINUSMINUS *);
  274 (* PLUS *);
  275 (* PLUSPLUS *);
  276 (* STAR *);
  277 (* SLASH *);
  278 (* PERCENT *);
  279 (* EQ *);
  280 (* LTEQ *);
  281 (* GTEQ *);
  282 (* GT *);
  283 (* LT *);
  284 (* EQEQ *);
  285 (* BANGEQ *);
  286 (* LTCOLON *);
  287 (* COLONGT *);
  288 (* PLUSEQ *);
  289 (* MINUSEQ *);
  290 (* STAREQ *);
  291 (* SLASHEQ *);
  292 (* PERCENTEQ *);
  293 (* AMPAMP *);
  294 (* BARBAR *);
  295 (* EQGT *);
  296 (* LTEQGT *);
  297 (* EXCLAM *);
  298 (* IF *);
  299 (* ELSE *);
  300 (* RETURN *);
  301 (* WHILE *);
  302 (* PACK *);
  303 (* UNPACK *);
  304 (* TYPE *);
  305 (* INVARIANT *);
  306 (* WITH *);
  307 (* VARIANT *);
  308 (* INTEGER *);
  309 (* BOOLEAN *);
  310 (* REAL *);
  311 (* UNIT *);
  312 (* ASSIGNS *);
  313 (* ASSUMES *);
  314 (* BEHAVIOR *);
  315 (* ENSURES *);
  316 (* REQUIRES *);
  317 (* BSFORALL *);
  318 (* BSOFFSET_MAX *);
  319 (* BSOFFSET_MIN *);
  320 (* BSOLD *);
  321 (* BSRESULT *);
  322 (* AXIOM *);
    0 (* EOF *);
    0|]

let yytransl_block = [|
  257 (* IDENTIFIER *);
  258 (* CONSTANT *);
  259 (* STRING_LITERAL *);
    0|]

let yylhs = "\255\255\
\001\000\001\000\002\000\002\000\002\000\004\000\006\000\006\000\
\007\000\007\000\007\000\008\000\009\000\012\000\012\000\013\000\
\013\000\014\000\010\000\010\000\010\000\010\000\010\000\010\000\
\010\000\010\000\010\000\010\000\015\000\015\000\016\000\016\000\
\017\000\017\000\018\000\018\000\003\000\005\000\021\000\021\000\
\021\000\021\000\022\000\022\000\022\000\022\000\022\000\022\000\
\022\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
\019\000\019\000\024\000\024\000\024\000\024\000\025\000\025\000\
\025\000\026\000\027\000\027\000\027\000\027\000\027\000\027\000\
\027\000\028\000\028\000\028\000\029\000\030\000\031\000\032\000\
\032\000\033\000\033\000\034\000\034\000\023\000\023\000\035\000\
\035\000\035\000\035\000\035\000\035\000\011\000\011\000\011\000\
\011\000\036\000\036\000\037\000\037\000\020\000\038\000\038\000\
\040\000\040\000\041\000\041\000\042\000\043\000\044\000\045\000\
\045\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
\000\000"

let yylen = "\002\000\
\002\000\001\000\001\000\001\000\001\000\007\000\000\000\002\000\
\000\000\002\000\002\000\003\000\008\000\002\000\003\000\001\000\
\003\000\002\000\001\000\001\000\001\000\001\000\001\000\004\000\
\004\000\005\000\006\000\005\000\000\000\002\000\003\000\008\000\
\000\000\003\000\000\000\003\000\005\000\004\000\001\000\001\000\
\001\000\003\000\001\000\003\000\004\000\004\000\004\000\004\000\
\003\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\001\000\003\000\001\000\003\000\003\000\003\000\001\000\003\000\
\003\000\001\000\001\000\003\000\003\000\003\000\003\000\003\000\
\003\000\001\000\003\000\003\000\001\000\001\000\001\000\001\000\
\003\000\001\000\003\000\001\000\005\000\001\000\003\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\005\000\003\000\
\003\000\001\000\003\000\003\000\005\000\003\000\000\000\002\000\
\001\000\002\000\005\000\007\000\004\000\006\000\003\000\005\000\
\005\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\019\000\020\000\021\000\022\000\
\000\000\002\000\121\000\000\000\003\000\004\000\005\000\000\000\
\000\000\000\000\000\000\001\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\025\000\000\000\000\000\024\000\000\000\
\000\000\039\000\041\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\040\000\000\000\000\000\
\000\000\094\000\000\000\000\000\067\000\000\000\000\000\078\000\
\079\000\080\000\000\000\000\000\086\000\014\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\026\000\028\000\
\008\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\051\000\050\000\088\000\089\000\090\000\091\000\092\000\093\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\018\000\015\000\000\000\000\000\000\000\000\000\037\000\
\030\000\027\000\000\000\000\000\000\000\000\000\000\000\042\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\044\000\
\000\000\000\000\049\000\087\000\000\000\000\000\000\000\000\000\
\000\000\000\000\070\000\071\000\069\000\068\000\072\000\073\000\
\000\000\000\000\081\000\000\000\000\000\017\000\000\000\031\000\
\000\000\105\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\114\000\119\000\000\000\000\000\115\000\116\000\117\000\
\118\000\120\000\000\000\006\000\010\000\011\000\000\000\000\000\
\000\000\047\000\048\000\046\000\045\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\106\000\
\102\000\104\000\000\000\012\000\099\000\000\000\058\000\085\000\
\000\000\000\000\000\000\000\000\111\000\000\000\000\000\000\000\
\000\000\100\000\000\000\000\000\034\000\000\000\000\000\000\000\
\000\000\109\000\000\000\000\000\000\000\000\000\036\000\000\000\
\000\000\000\000\112\000\113\000\101\000\000\000\032\000\000\000\
\000\000\000\000\108\000\000\000\013\000\110\000"

let yydgoto = "\002\000\
\011\000\012\000\013\000\014\000\015\000\033\000\124\000\125\000\
\126\000\168\000\169\000\027\000\064\000\065\000\068\000\069\000\
\193\000\211\000\137\000\170\000\048\000\049\000\050\000\051\000\
\052\000\053\000\054\000\055\000\056\000\057\000\058\000\059\000\
\060\000\061\000\097\000\130\000\171\000\172\000\173\000\174\000\
\175\000\176\000\215\000\177\000\178\000"

let yysindex = "\030\000\
\241\000\000\000\071\255\087\255\000\000\000\000\000\000\000\000\
\095\255\000\000\000\000\241\000\000\000\000\000\000\000\110\255\
\016\255\112\255\107\255\000\000\146\255\039\255\020\255\156\255\
\090\255\031\255\221\254\000\000\147\255\158\255\000\000\150\255\
\165\255\000\000\000\000\090\255\164\255\164\255\164\255\164\255\
\164\255\001\255\191\255\198\255\202\255\000\000\149\255\218\255\
\162\003\000\000\157\255\128\255\000\000\160\255\189\255\000\000\
\000\000\000\000\193\255\253\254\000\000\000\000\230\255\227\255\
\228\255\241\255\090\255\229\255\221\254\239\255\000\000\000\000\
\000\000\046\255\012\255\235\255\235\255\235\255\235\255\235\255\
\242\255\090\255\090\255\090\255\090\255\090\255\128\004\249\255\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\164\255\164\255\164\255\164\255\164\255\164\255\164\255\164\255\
\164\255\164\255\250\255\251\255\164\255\164\255\164\255\090\255\
\164\255\000\000\000\000\001\255\246\255\002\255\109\004\000\000\
\000\000\000\000\003\000\254\255\046\255\046\255\006\000\000\000\
\252\255\255\255\019\255\035\255\076\255\226\255\149\255\000\000\
\038\000\032\000\000\000\000\000\145\255\145\255\145\255\145\255\
\157\255\157\255\000\000\000\000\000\000\000\000\000\000\000\000\
\160\255\160\255\000\000\254\254\193\255\000\000\210\255\000\000\
\071\255\000\000\041\000\090\255\090\255\042\000\043\000\047\000\
\004\255\000\000\000\000\044\000\109\004\000\000\000\000\000\000\
\000\000\000\000\048\000\000\000\000\000\000\000\046\000\242\255\
\090\255\000\000\000\000\000\000\000\000\164\255\164\255\090\255\
\005\000\090\255\078\255\065\255\090\255\090\255\005\255\000\000\
\000\000\000\000\058\000\000\000\000\000\149\255\000\000\000\000\
\086\255\164\255\007\000\082\255\000\000\090\255\109\004\088\255\
\097\255\000\000\090\255\055\000\000\000\052\000\090\255\109\004\
\099\255\000\000\053\000\054\000\101\255\051\000\000\000\108\255\
\028\000\025\000\000\000\000\000\000\000\090\255\000\000\109\004\
\090\255\121\255\000\000\134\255\000\000\000\000"

let yyrindex = "\000\000\
\000\000\000\000\098\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\094\000\
\000\000\000\000\095\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\253\002\001\000\
\098\001\000\000\056\002\213\002\000\000\244\002\120\003\000\000\
\000\000\000\000\151\003\227\003\000\000\000\000\000\000\000\000\
\097\000\000\000\000\000\000\000\095\000\000\000\000\000\000\000\
\000\000\096\000\000\000\057\000\113\000\169\000\225\000\042\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\100\000\000\000\
\000\000\000\000\000\000\000\000\096\000\096\000\000\000\000\000\
\093\000\000\000\000\000\000\000\000\000\029\004\038\004\000\000\
\000\000\022\255\000\000\000\000\154\001\210\001\010\002\098\001\
\101\002\157\002\000\000\000\000\000\000\000\000\000\000\000\000\
\019\003\075\003\000\000\000\000\207\003\000\000\148\255\000\000\
\183\004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\100\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\049\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\053\004\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\192\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000"

let yygindex = "\000\000\
\101\001\000\000\000\000\000\000\000\000\000\000\004\000\000\000\
\000\000\008\000\234\255\000\000\255\000\000\000\047\001\000\000\
\000\000\000\000\085\255\049\001\000\000\223\255\169\255\119\000\
\000\000\109\000\114\000\000\000\000\000\000\000\008\001\007\001\
\000\000\186\000\000\000\194\000\000\000\210\000\062\255\000\000\
\000\000\000\000\000\000\000\000\000\000"

let yytablesize = 1503
let yytable = "\138\000\
\043\000\003\000\047\000\076\000\077\000\078\000\079\000\080\000\
\016\000\140\000\191\000\112\000\160\000\075\000\200\000\218\000\
\128\000\022\000\207\000\016\000\226\000\030\000\066\000\186\000\
\067\000\023\000\057\000\219\000\031\000\233\000\001\000\003\000\
\057\000\063\000\113\000\062\000\085\000\086\000\222\000\187\000\
\085\000\086\000\085\000\086\000\118\000\243\000\003\000\028\000\
\029\000\081\000\085\000\086\000\005\000\006\000\007\000\008\000\
\055\000\085\000\086\000\131\000\132\000\133\000\134\000\135\000\
\141\000\142\000\143\000\144\000\144\000\144\000\144\000\144\000\
\144\000\085\000\086\000\144\000\144\000\144\000\017\000\144\000\
\188\000\127\000\005\000\006\000\007\000\008\000\224\000\018\000\
\213\000\156\000\034\000\035\000\227\000\036\000\123\000\019\000\
\221\000\005\000\006\000\007\000\008\000\228\000\138\000\085\000\
\086\000\037\000\038\000\039\000\040\000\234\000\021\000\237\000\
\053\000\214\000\085\000\086\000\085\000\086\000\239\000\025\000\
\085\000\086\000\138\000\063\000\085\000\086\000\085\000\086\000\
\181\000\182\000\041\000\245\000\127\000\127\000\024\000\085\000\
\086\000\085\000\086\000\085\000\086\000\195\000\196\000\101\000\
\246\000\102\000\085\000\086\000\070\000\026\000\042\000\043\000\
\044\000\045\000\046\000\071\000\032\000\144\000\088\000\085\000\
\086\000\089\000\206\000\090\000\034\000\035\000\072\000\036\000\
\054\000\209\000\074\000\212\000\085\000\086\000\216\000\217\000\
\098\000\099\000\100\000\037\000\038\000\039\000\040\000\103\000\
\104\000\105\000\106\000\085\000\086\000\107\000\108\000\225\000\
\107\000\107\000\082\000\107\000\229\000\107\000\107\000\073\000\
\232\000\083\000\107\000\033\000\041\000\084\000\033\000\107\000\
\107\000\107\000\107\000\147\000\148\000\149\000\150\000\242\000\
\109\000\110\000\244\000\145\000\146\000\087\000\153\000\154\000\
\052\000\043\000\044\000\045\000\046\000\111\000\114\000\115\000\
\107\000\107\000\119\000\107\000\107\000\107\000\107\000\116\000\
\010\000\117\000\129\000\107\000\107\000\107\000\107\000\122\000\
\088\000\139\000\151\000\152\000\107\000\107\000\107\000\107\000\
\107\000\043\000\159\000\179\000\180\000\043\000\183\000\184\000\
\085\000\185\000\192\000\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\056\000\189\000\190\000\194\000\197\000\198\000\199\000\
\043\000\043\000\201\000\203\000\043\000\043\000\043\000\043\000\
\204\000\055\000\220\000\230\000\210\000\055\000\231\000\235\000\
\236\000\223\000\043\000\055\000\055\000\055\000\240\000\055\000\
\055\000\238\000\055\000\241\000\055\000\055\000\055\000\055\000\
\055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
\055\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
\055\000\059\000\023\000\007\000\029\000\016\000\009\000\098\000\
\055\000\055\000\103\000\035\000\055\000\055\000\055\000\055\000\
\020\000\053\000\158\000\121\000\120\000\053\000\155\000\157\000\
\208\000\205\000\055\000\053\000\053\000\053\000\202\000\053\000\
\053\000\000\000\053\000\000\000\053\000\053\000\053\000\053\000\
\053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
\053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
\053\000\060\000\000\000\000\000\000\000\000\000\000\000\000\000\
\053\000\053\000\000\000\000\000\053\000\053\000\053\000\053\000\
\000\000\054\000\000\000\000\000\000\000\054\000\000\000\000\000\
\000\000\000\000\053\000\054\000\054\000\054\000\000\000\054\000\
\054\000\000\000\054\000\000\000\054\000\054\000\054\000\054\000\
\054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
\054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
\054\000\061\000\000\000\000\000\000\000\000\000\000\000\000\000\
\054\000\054\000\000\000\000\000\054\000\054\000\054\000\054\000\
\000\000\052\000\000\000\000\000\000\000\052\000\000\000\000\000\
\000\000\000\000\054\000\052\000\052\000\052\000\000\000\052\000\
\052\000\003\000\052\000\000\000\052\000\052\000\052\000\052\000\
\052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
\052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
\052\000\062\000\000\000\000\000\000\000\000\000\000\000\000\000\
\052\000\052\000\000\000\000\000\052\000\052\000\052\000\052\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\004\000\000\000\052\000\000\000\005\000\006\000\007\000\008\000\
\000\000\000\000\056\000\000\000\000\000\000\000\056\000\000\000\
\000\000\000\000\009\000\000\000\056\000\056\000\056\000\063\000\
\056\000\056\000\000\000\056\000\000\000\056\000\056\000\056\000\
\056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
\056\000\056\000\056\000\056\000\056\000\056\000\056\000\056\000\
\056\000\056\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\056\000\056\000\000\000\000\000\056\000\056\000\056\000\
\056\000\000\000\059\000\000\000\065\000\000\000\059\000\000\000\
\000\000\000\000\000\000\056\000\059\000\059\000\059\000\000\000\
\059\000\059\000\000\000\059\000\000\000\059\000\059\000\059\000\
\000\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
\059\000\000\000\000\000\000\000\000\000\000\000\059\000\059\000\
\059\000\059\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\059\000\059\000\000\000\000\000\059\000\059\000\059\000\
\059\000\000\000\060\000\000\000\064\000\000\000\060\000\000\000\
\000\000\000\000\000\000\059\000\060\000\060\000\060\000\000\000\
\060\000\060\000\000\000\060\000\000\000\060\000\060\000\060\000\
\000\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
\060\000\000\000\000\000\000\000\000\000\000\000\060\000\060\000\
\060\000\060\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\060\000\060\000\000\000\000\000\060\000\060\000\060\000\
\060\000\000\000\061\000\000\000\066\000\000\000\061\000\000\000\
\000\000\000\000\000\000\060\000\061\000\061\000\061\000\000\000\
\061\000\061\000\000\000\061\000\000\000\061\000\061\000\061\000\
\000\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\000\000\000\000\074\000\000\000\000\000\061\000\061\000\
\061\000\061\000\000\000\000\000\038\000\000\000\000\000\000\000\
\000\000\061\000\061\000\000\000\000\000\061\000\061\000\061\000\
\061\000\000\000\062\000\000\000\000\000\000\000\062\000\000\000\
\000\000\000\000\075\000\061\000\062\000\062\000\062\000\000\000\
\062\000\062\000\000\000\062\000\000\000\062\000\062\000\062\000\
\000\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
\062\000\000\000\000\000\000\000\000\000\000\000\062\000\062\000\
\062\000\062\000\000\000\000\000\000\000\000\000\000\000\000\000\
\063\000\062\000\062\000\000\000\063\000\062\000\062\000\062\000\
\062\000\000\000\063\000\063\000\063\000\000\000\063\000\063\000\
\000\000\063\000\076\000\062\000\000\000\000\000\000\000\063\000\
\063\000\063\000\063\000\063\000\063\000\063\000\063\000\000\000\
\000\000\000\000\000\000\000\000\063\000\063\000\063\000\063\000\
\000\000\000\000\000\000\000\000\000\000\065\000\000\000\063\000\
\063\000\065\000\000\000\063\000\063\000\063\000\063\000\065\000\
\065\000\065\000\000\000\065\000\065\000\000\000\065\000\077\000\
\000\000\063\000\000\000\000\000\065\000\065\000\065\000\065\000\
\065\000\065\000\065\000\065\000\000\000\000\000\000\000\000\000\
\000\000\065\000\065\000\065\000\065\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\065\000\082\000\000\000\
\065\000\065\000\065\000\065\000\000\000\064\000\000\000\000\000\
\000\000\064\000\000\000\000\000\000\000\000\000\065\000\064\000\
\064\000\064\000\000\000\064\000\064\000\000\000\064\000\000\000\
\000\000\000\000\000\000\000\000\064\000\064\000\064\000\064\000\
\064\000\064\000\064\000\064\000\000\000\000\000\000\000\000\000\
\000\000\064\000\064\000\064\000\064\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\064\000\064\000\083\000\000\000\
\064\000\064\000\064\000\064\000\000\000\066\000\000\000\000\000\
\000\000\066\000\000\000\000\000\000\000\000\000\064\000\066\000\
\066\000\066\000\084\000\066\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\066\000\066\000\066\000\066\000\
\066\000\066\000\066\000\066\000\074\000\000\000\000\000\000\000\
\074\000\066\000\066\000\066\000\066\000\038\000\074\000\074\000\
\074\000\000\000\074\000\000\000\066\000\066\000\000\000\000\000\
\066\000\066\000\066\000\066\000\000\000\000\000\000\000\074\000\
\074\000\000\000\000\000\075\000\000\000\000\000\066\000\075\000\
\074\000\074\000\074\000\074\000\096\000\075\000\075\000\075\000\
\000\000\075\000\000\000\074\000\074\000\097\000\000\000\074\000\
\074\000\074\000\074\000\000\000\038\000\000\000\075\000\075\000\
\038\000\038\000\038\000\038\000\095\000\074\000\000\000\075\000\
\075\000\075\000\075\000\000\000\000\000\000\000\038\000\000\000\
\000\000\000\000\075\000\075\000\000\000\000\000\075\000\075\000\
\075\000\075\000\000\000\076\000\000\000\000\000\000\000\076\000\
\000\000\000\000\000\000\000\000\075\000\076\000\076\000\076\000\
\000\000\076\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\076\000\076\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\076\000\
\076\000\076\000\076\000\000\000\000\000\000\000\000\000\000\000\
\077\000\000\000\076\000\076\000\077\000\000\000\076\000\076\000\
\076\000\076\000\077\000\077\000\077\000\000\000\077\000\000\000\
\000\000\000\000\000\000\000\000\076\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\082\000\
\000\000\000\000\000\000\082\000\077\000\077\000\077\000\077\000\
\000\000\082\000\082\000\082\000\000\000\082\000\000\000\077\000\
\077\000\000\000\000\000\077\000\077\000\077\000\077\000\088\000\
\000\000\000\000\089\000\000\000\090\000\000\000\000\000\000\000\
\091\000\077\000\000\000\000\000\082\000\082\000\082\000\000\000\
\000\000\092\000\093\000\094\000\095\000\096\000\082\000\082\000\
\000\000\000\000\082\000\082\000\082\000\082\000\000\000\083\000\
\000\000\000\000\000\000\083\000\000\000\000\000\000\000\000\000\
\082\000\083\000\083\000\083\000\000\000\083\000\000\000\000\000\
\000\000\000\000\000\000\084\000\000\000\000\000\000\000\084\000\
\000\000\000\000\000\000\000\000\000\000\084\000\084\000\084\000\
\000\000\000\000\000\000\000\000\083\000\083\000\083\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\083\000\083\000\
\000\000\000\000\083\000\083\000\083\000\083\000\000\000\000\000\
\000\000\084\000\084\000\000\000\000\000\000\000\000\000\000\000\
\083\000\000\000\084\000\084\000\000\000\000\000\084\000\084\000\
\084\000\084\000\000\000\000\000\000\000\096\000\000\000\000\000\
\000\000\096\000\000\000\000\000\084\000\000\000\097\000\096\000\
\000\000\096\000\097\000\000\000\000\000\000\000\000\000\000\000\
\097\000\000\000\097\000\000\000\000\000\095\000\000\000\000\000\
\000\000\095\000\000\000\000\000\000\000\000\000\000\000\095\000\
\000\000\095\000\000\000\000\000\096\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\096\000\096\000\000\000\000\000\
\096\000\096\000\096\000\096\000\000\000\097\000\097\000\000\000\
\000\000\097\000\097\000\097\000\097\000\000\000\096\000\000\000\
\000\000\000\000\000\000\000\000\095\000\095\000\000\000\097\000\
\095\000\095\000\095\000\095\000\000\000\161\000\035\000\000\000\
\036\000\000\000\119\000\000\000\000\000\000\000\095\000\162\000\
\000\000\000\000\000\000\000\000\037\000\038\000\039\000\040\000\
\034\000\035\000\000\000\036\000\136\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\037\000\
\038\000\039\000\040\000\000\000\000\000\041\000\163\000\000\000\
\164\000\165\000\166\000\167\000\000\000\000\000\000\000\000\000\
\005\000\006\000\007\000\008\000\000\000\000\000\000\000\000\000\
\041\000\042\000\043\000\044\000\045\000\046\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\023\000\
\000\000\000\000\039\000\000\000\000\000\043\000\044\000\045\000\
\046\000\039\000\000\000\000\000\039\000\039\000\039\000\039\000\
\039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
\039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
\039\000\039\000\039\000\039\000\039\000\039\000\039\000"

let yycheck = "\087\000\
\000\000\001\001\025\000\037\000\038\000\039\000\040\000\041\000\
\001\000\097\000\013\001\015\001\011\001\036\000\011\001\011\001\
\005\001\002\001\190\000\012\000\215\000\002\001\058\001\005\001\
\060\001\010\001\005\001\023\001\009\001\224\000\001\000\001\001\
\011\001\026\000\038\001\005\001\039\001\040\001\210\000\005\001\
\039\001\040\001\039\001\040\001\067\000\240\000\001\001\009\001\
\010\001\042\000\039\001\040\001\052\001\053\001\054\001\055\001\
\000\000\039\001\040\001\082\000\083\000\084\000\085\000\086\000\
\098\000\099\000\100\000\101\000\102\000\103\000\104\000\105\000\
\106\000\039\001\040\001\109\000\110\000\111\000\008\001\113\000\
\005\001\074\000\052\001\053\001\054\001\055\001\005\001\001\001\
\011\001\112\000\001\001\002\001\005\001\004\001\049\001\001\001\
\011\001\052\001\053\001\054\001\055\001\005\001\190\000\039\001\
\040\001\016\001\017\001\018\001\019\001\011\001\001\001\011\001\
\000\000\049\001\039\001\040\001\039\001\040\001\011\001\013\001\
\039\001\040\001\210\000\116\000\039\001\040\001\039\001\040\001\
\125\000\126\000\041\001\011\001\125\000\126\000\023\001\039\001\
\040\001\039\001\040\001\039\001\040\001\164\000\165\000\016\001\
\011\001\018\001\039\001\040\001\002\001\004\001\061\001\062\001\
\063\001\064\001\065\001\009\001\001\001\191\000\014\001\039\001\
\040\001\017\001\185\000\019\001\001\001\002\001\009\001\004\001\
\000\000\192\000\006\001\194\000\039\001\040\001\197\000\198\000\
\020\001\021\001\022\001\016\001\017\001\018\001\019\001\024\001\
\025\001\026\001\027\001\039\001\040\001\030\001\031\001\214\000\
\001\001\002\001\004\001\004\001\219\000\006\001\007\001\050\001\
\223\000\004\001\011\001\056\001\041\001\004\001\059\001\016\001\
\017\001\018\001\019\001\103\000\104\000\105\000\106\000\238\000\
\028\001\029\001\241\000\101\000\102\000\004\001\109\000\110\000\
\000\000\062\001\063\001\064\001\065\001\037\001\001\001\005\001\
\041\001\042\001\006\001\044\001\045\001\046\001\047\001\012\001\
\000\000\001\001\001\001\052\001\053\001\054\001\055\001\009\001\
\014\001\001\001\001\001\001\001\061\001\062\001\063\001\064\001\
\065\001\001\001\013\001\001\001\007\001\005\001\001\001\012\001\
\039\001\011\001\057\001\011\001\012\001\013\001\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\000\000\005\001\012\001\004\001\004\001\004\001\001\001\
\048\001\049\001\007\001\004\001\052\001\053\001\054\001\055\001\
\011\001\001\001\001\001\005\001\056\001\005\001\011\001\011\001\
\011\001\059\001\066\001\011\001\012\001\013\001\043\001\015\001\
\016\001\023\001\018\001\051\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\000\000\001\001\006\001\006\001\005\001\007\001\011\001\
\048\001\049\001\007\001\059\001\052\001\053\001\054\001\055\001\
\012\000\001\001\116\000\069\000\068\000\005\001\111\000\113\000\
\191\000\184\000\066\001\011\001\012\001\013\001\173\000\015\001\
\016\001\255\255\018\001\255\255\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
\048\001\049\001\255\255\255\255\052\001\053\001\054\001\055\001\
\255\255\001\001\255\255\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\066\001\011\001\012\001\013\001\255\255\015\001\
\016\001\255\255\018\001\255\255\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
\048\001\049\001\255\255\255\255\052\001\053\001\054\001\055\001\
\255\255\001\001\255\255\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\066\001\011\001\012\001\013\001\255\255\015\001\
\016\001\001\001\018\001\255\255\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
\048\001\049\001\255\255\255\255\052\001\053\001\054\001\055\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\048\001\255\255\066\001\255\255\052\001\053\001\054\001\055\001\
\255\255\255\255\001\001\255\255\255\255\255\255\005\001\255\255\
\255\255\255\255\066\001\255\255\011\001\012\001\013\001\000\000\
\015\001\016\001\255\255\018\001\255\255\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\048\001\049\001\255\255\255\255\052\001\053\001\054\001\
\055\001\255\255\001\001\255\255\000\000\255\255\005\001\255\255\
\255\255\255\255\255\255\066\001\011\001\012\001\013\001\255\255\
\015\001\016\001\255\255\018\001\255\255\020\001\021\001\022\001\
\255\255\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\255\255\255\255\255\255\255\255\255\255\037\001\038\001\
\039\001\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\048\001\049\001\255\255\255\255\052\001\053\001\054\001\
\055\001\255\255\001\001\255\255\000\000\255\255\005\001\255\255\
\255\255\255\255\255\255\066\001\011\001\012\001\013\001\255\255\
\015\001\016\001\255\255\018\001\255\255\020\001\021\001\022\001\
\255\255\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\255\255\255\255\255\255\255\255\255\255\037\001\038\001\
\039\001\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\048\001\049\001\255\255\255\255\052\001\053\001\054\001\
\055\001\255\255\001\001\255\255\000\000\255\255\005\001\255\255\
\255\255\255\255\255\255\066\001\011\001\012\001\013\001\255\255\
\015\001\016\001\255\255\018\001\255\255\020\001\021\001\022\001\
\255\255\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\255\255\255\255\000\000\255\255\255\255\037\001\038\001\
\039\001\040\001\255\255\255\255\000\000\255\255\255\255\255\255\
\255\255\048\001\049\001\255\255\255\255\052\001\053\001\054\001\
\055\001\255\255\001\001\255\255\255\255\255\255\005\001\255\255\
\255\255\255\255\000\000\066\001\011\001\012\001\013\001\255\255\
\015\001\016\001\255\255\018\001\255\255\020\001\021\001\022\001\
\255\255\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\255\255\255\255\255\255\255\255\255\255\037\001\038\001\
\039\001\040\001\255\255\255\255\255\255\255\255\255\255\255\255\
\001\001\048\001\049\001\255\255\005\001\052\001\053\001\054\001\
\055\001\255\255\011\001\012\001\013\001\255\255\015\001\016\001\
\255\255\018\001\000\000\066\001\255\255\255\255\255\255\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\255\255\
\255\255\255\255\255\255\255\255\037\001\038\001\039\001\040\001\
\255\255\255\255\255\255\255\255\255\255\001\001\255\255\048\001\
\049\001\005\001\255\255\052\001\053\001\054\001\055\001\011\001\
\012\001\013\001\255\255\015\001\016\001\255\255\018\001\000\000\
\255\255\066\001\255\255\255\255\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\255\255\255\255\255\255\255\255\
\255\255\037\001\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\048\001\049\001\000\000\255\255\
\052\001\053\001\054\001\055\001\255\255\001\001\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\066\001\011\001\
\012\001\013\001\255\255\015\001\016\001\255\255\018\001\255\255\
\255\255\255\255\255\255\255\255\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\255\255\255\255\255\255\255\255\
\255\255\037\001\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\048\001\049\001\000\000\255\255\
\052\001\053\001\054\001\055\001\255\255\001\001\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\066\001\011\001\
\012\001\013\001\000\000\015\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\001\001\255\255\255\255\255\255\
\005\001\037\001\038\001\039\001\040\001\001\001\011\001\012\001\
\013\001\255\255\015\001\255\255\048\001\049\001\255\255\255\255\
\052\001\053\001\054\001\055\001\255\255\255\255\255\255\028\001\
\029\001\255\255\255\255\001\001\255\255\255\255\066\001\005\001\
\037\001\038\001\039\001\040\001\000\000\011\001\012\001\013\001\
\255\255\015\001\255\255\048\001\049\001\000\000\255\255\052\001\
\053\001\054\001\055\001\255\255\048\001\255\255\028\001\029\001\
\052\001\053\001\054\001\055\001\000\000\066\001\255\255\037\001\
\038\001\039\001\040\001\255\255\255\255\255\255\066\001\255\255\
\255\255\255\255\048\001\049\001\255\255\255\255\052\001\053\001\
\054\001\055\001\255\255\001\001\255\255\255\255\255\255\005\001\
\255\255\255\255\255\255\255\255\066\001\011\001\012\001\013\001\
\255\255\015\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\028\001\029\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\037\001\
\038\001\039\001\040\001\255\255\255\255\255\255\255\255\255\255\
\001\001\255\255\048\001\049\001\005\001\255\255\052\001\053\001\
\054\001\055\001\011\001\012\001\013\001\255\255\015\001\255\255\
\255\255\255\255\255\255\255\255\066\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\001\001\
\255\255\255\255\255\255\005\001\037\001\038\001\039\001\040\001\
\255\255\011\001\012\001\013\001\255\255\015\001\255\255\048\001\
\049\001\255\255\255\255\052\001\053\001\054\001\055\001\014\001\
\255\255\255\255\017\001\255\255\019\001\255\255\255\255\255\255\
\023\001\066\001\255\255\255\255\038\001\039\001\040\001\255\255\
\255\255\032\001\033\001\034\001\035\001\036\001\048\001\049\001\
\255\255\255\255\052\001\053\001\054\001\055\001\255\255\001\001\
\255\255\255\255\255\255\005\001\255\255\255\255\255\255\255\255\
\066\001\011\001\012\001\013\001\255\255\015\001\255\255\255\255\
\255\255\255\255\255\255\001\001\255\255\255\255\255\255\005\001\
\255\255\255\255\255\255\255\255\255\255\011\001\012\001\013\001\
\255\255\255\255\255\255\255\255\038\001\039\001\040\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\048\001\049\001\
\255\255\255\255\052\001\053\001\054\001\055\001\255\255\255\255\
\255\255\039\001\040\001\255\255\255\255\255\255\255\255\255\255\
\066\001\255\255\048\001\049\001\255\255\255\255\052\001\053\001\
\054\001\055\001\255\255\255\255\255\255\001\001\255\255\255\255\
\255\255\005\001\255\255\255\255\066\001\255\255\001\001\011\001\
\255\255\013\001\005\001\255\255\255\255\255\255\255\255\255\255\
\011\001\255\255\013\001\255\255\255\255\001\001\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\255\255\011\001\
\255\255\013\001\255\255\255\255\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\048\001\049\001\255\255\255\255\
\052\001\053\001\054\001\055\001\255\255\048\001\049\001\255\255\
\255\255\052\001\053\001\054\001\055\001\255\255\066\001\255\255\
\255\255\255\255\255\255\255\255\048\001\049\001\255\255\066\001\
\052\001\053\001\054\001\055\001\255\255\001\001\002\001\255\255\
\004\001\255\255\006\001\255\255\255\255\255\255\066\001\011\001\
\255\255\255\255\255\255\255\255\016\001\017\001\018\001\019\001\
\001\001\002\001\255\255\004\001\005\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\016\001\
\017\001\018\001\019\001\255\255\255\255\041\001\042\001\255\255\
\044\001\045\001\046\001\047\001\255\255\255\255\255\255\255\255\
\052\001\053\001\054\001\055\001\255\255\255\255\255\255\255\255\
\041\001\061\001\062\001\063\001\064\001\065\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\001\001\
\255\255\255\255\004\001\255\255\255\255\062\001\063\001\064\001\
\065\001\011\001\255\255\255\255\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001"

let yynames_const = "\
  LPAR\000\
  RPAR\000\
  LBRACE\000\
  RBRACE\000\
  LSQUARE\000\
  RSQUARE\000\
  DOTDOT\000\
  SEMICOLON\000\
  COMMA\000\
  COLON\000\
  DOT\000\
  QUESTION\000\
  MINUS\000\
  MINUSMINUS\000\
  PLUS\000\
  PLUSPLUS\000\
  STAR\000\
  SLASH\000\
  PERCENT\000\
  EQ\000\
  LTEQ\000\
  GTEQ\000\
  GT\000\
  LT\000\
  EQEQ\000\
  BANGEQ\000\
  LTCOLON\000\
  COLONGT\000\
  PLUSEQ\000\
  MINUSEQ\000\
  STAREQ\000\
  SLASHEQ\000\
  PERCENTEQ\000\
  AMPAMP\000\
  BARBAR\000\
  EQGT\000\
  LTEQGT\000\
  EXCLAM\000\
  IF\000\
  ELSE\000\
  RETURN\000\
  WHILE\000\
  PACK\000\
  UNPACK\000\
  TYPE\000\
  INVARIANT\000\
  WITH\000\
  VARIANT\000\
  INTEGER\000\
  BOOLEAN\000\
  REAL\000\
  UNIT\000\
  ASSIGNS\000\
  ASSUMES\000\
  BEHAVIOR\000\
  ENSURES\000\
  REQUIRES\000\
  BSFORALL\000\
  BSOFFSET_MAX\000\
  BSOFFSET_MIN\000\
  BSOLD\000\
  BSRESULT\000\
  AXIOM\000\
  EOF\000\
  "

let yynames_block = "\
  IDENTIFIER\000\
  CONSTANT\000\
  STRING_LITERAL\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Jc_ast.pdecl list) in
    Obj.repr(
# 160 "jc/jc_parser.mly"
    ( _1::_2 )
# 798 "jc/jc_parser.ml"
               : Jc_ast.pdecl list))
; (fun __caml_parser_env ->
    Obj.repr(
# 162 "jc/jc_parser.mly"
    ( [] )
# 804 "jc/jc_parser.ml"
               : Jc_ast.pdecl list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'function_definition) in
    Obj.repr(
# 167 "jc/jc_parser.mly"
    ( _1 )
# 811 "jc/jc_parser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'type_definition) in
    Obj.repr(
# 169 "jc/jc_parser.mly"
    ( _1 )
# 818 "jc/jc_parser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'axiom_definition) in
    Obj.repr(
# 171 "jc/jc_parser.mly"
    ( _1 )
# 825 "jc/jc_parser.ml"
               : 'decl))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'extends) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'field_declaration_list) in
    Obj.repr(
# 185 "jc/jc_parser.mly"
    ( let (f,i) = _6 in locate_decl (JCPDtype(_2,_4,f,i)) )
# 834 "jc/jc_parser.ml"
               : 'type_definition))
; (fun __caml_parser_env ->
    Obj.repr(
# 190 "jc/jc_parser.mly"
    ( None )
# 840 "jc/jc_parser.ml"
               : 'extends))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 192 "jc/jc_parser.mly"
    ( Some _1 )
# 847 "jc/jc_parser.ml"
               : 'extends))
; (fun __caml_parser_env ->
    Obj.repr(
# 197 "jc/jc_parser.mly"
    ( ([],[]) )
# 853 "jc/jc_parser.ml"
               : 'field_declaration_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'field_declaration) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'field_declaration_list) in
    Obj.repr(
# 199 "jc/jc_parser.mly"
    ( let (f,i) = _2 in (_1::f,i) )
# 861 "jc/jc_parser.ml"
               : 'field_declaration_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'invariant) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'field_declaration_list) in
    Obj.repr(
# 201 "jc/jc_parser.mly"
    ( let (f,i) = _2 in (f,_1::i) )
# 869 "jc/jc_parser.ml"
               : 'field_declaration_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'type_expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 206 "jc/jc_parser.mly"
    ( (_1,_2) )
# 877 "jc/jc_parser.ml"
               : 'field_declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 211 "jc/jc_parser.mly"
    ( (_2,_4,_7) )
# 886 "jc/jc_parser.ml"
               : 'invariant))
; (fun __caml_parser_env ->
    Obj.repr(
# 223 "jc/jc_parser.mly"
    ( [] )
# 892 "jc/jc_parser.ml"
               : 'parameters))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'parameter_comma_list) in
    Obj.repr(
# 225 "jc/jc_parser.mly"
    ( _2 )
# 899 "jc/jc_parser.ml"
               : 'parameters))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_declaration) in
    Obj.repr(
# 230 "jc/jc_parser.mly"
    ( [_1] )
# 906 "jc/jc_parser.ml"
               : 'parameter_comma_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_declaration) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_comma_list) in
    Obj.repr(
# 232 "jc/jc_parser.mly"
    ( _1 :: _3 )
# 914 "jc/jc_parser.ml"
               : 'parameter_comma_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'type_expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 237 "jc/jc_parser.mly"
    ( (_1,_2) )
# 922 "jc/jc_parser.ml"
               : 'parameter_declaration))
; (fun __caml_parser_env ->
    Obj.repr(
# 243 "jc/jc_parser.mly"
    ( locate_type (JCPTnative Tinteger) )
# 928 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    Obj.repr(
# 245 "jc/jc_parser.mly"
    ( locate_type (JCPTnative Tboolean) )
# 934 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    Obj.repr(
# 247 "jc/jc_parser.mly"
    ( locate_type (JCPTnative Treal) )
# 940 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    Obj.repr(
# 249 "jc/jc_parser.mly"
    ( locate_type (JCPTnative Tunit) )
# 946 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 251 "jc/jc_parser.mly"
    ( locate_type (JCPTidentifier _1) )
# 953 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    Obj.repr(
# 253 "jc/jc_parser.mly"
    ( locate_type (JCPTpointer(_1,0,-1)) )
# 960 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Jc_ast.const) in
    Obj.repr(
# 255 "jc/jc_parser.mly"
    ( let n = int_of_constant (loc_i 3) _3 in
      locate_type (JCPTpointer(_1,n,n)) )
# 969 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Jc_ast.const) in
    Obj.repr(
# 258 "jc/jc_parser.mly"
    ( let n = int_of_constant (loc_i 3) _3 in
      locate_type (JCPTpointer(_1,n,n-1)) )
# 978 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Jc_ast.const) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Jc_ast.const) in
    Obj.repr(
# 261 "jc/jc_parser.mly"
    ( let n = int_of_constant (loc_i 3) _3 in
      let m = int_of_constant (loc_i 5) _5 in
      locate_type (JCPTpointer(_1,n,m)) )
# 989 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Jc_ast.const) in
    Obj.repr(
# 265 "jc/jc_parser.mly"
    ( let m = int_of_constant (loc_i 4) _4 in
      locate_type (JCPTpointer(_1,m+1,m)) )
# 998 "jc/jc_parser.ml"
               : 'type_expr))
; (fun __caml_parser_env ->
    Obj.repr(
# 271 "jc/jc_parser.mly"
    ( [] )
# 1004 "jc/jc_parser.ml"
               : 'function_specification))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'spec_clause) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'function_specification) in
    Obj.repr(
# 273 "jc/jc_parser.mly"
    ( _1::_2 )
# 1012 "jc/jc_parser.ml"
               : 'function_specification))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 278 "jc/jc_parser.mly"
    ( JCPCrequires(_2) )
# 1019 "jc/jc_parser.ml"
               : 'spec_clause))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 6 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : 'assumes) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'assigns) in
    let _7 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 280 "jc/jc_parser.mly"
    ( JCPCbehavior(_2,_4,_5,_7) )
# 1029 "jc/jc_parser.ml"
               : 'spec_clause))
; (fun __caml_parser_env ->
    Obj.repr(
# 286 "jc/jc_parser.mly"
    ( None )
# 1035 "jc/jc_parser.ml"
               : 'assumes))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 288 "jc/jc_parser.mly"
    ( Some _2 )
# 1042 "jc/jc_parser.ml"
               : 'assumes))
; (fun __caml_parser_env ->
    Obj.repr(
# 293 "jc/jc_parser.mly"
    ( None )
# 1048 "jc/jc_parser.ml"
               : 'assigns))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'argument_expression_list) in
    Obj.repr(
# 295 "jc/jc_parser.mly"
    ( Some _2 )
# 1055 "jc/jc_parser.ml"
               : 'assigns))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'type_expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'parameters) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'function_specification) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'compound_statement) in
    Obj.repr(
# 301 "jc/jc_parser.mly"
    ( locate_decl (JCPDfun(_1, _2, _3, _4, _5)) )
# 1066 "jc/jc_parser.ml"
               : 'function_definition))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 310 "jc/jc_parser.mly"
    ( locate_decl( JCPDaxiom(_2,_4)) )
# 1074 "jc/jc_parser.ml"
               : 'axiom_definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 320 "jc/jc_parser.mly"
    ( locate_expr (JCPEvar _1) )
# 1081 "jc/jc_parser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 322 "jc/jc_parser.mly"
    ( locate_expr (JCPEvar "\\result") )
# 1087 "jc/jc_parser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Jc_ast.const) in
    Obj.repr(
# 324 "jc/jc_parser.mly"
    ( locate_expr (JCPEconst _1) )
# 1094 "jc/jc_parser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 329 "jc/jc_parser.mly"
                       ( _2 )
# 1101 "jc/jc_parser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_expression) in
    Obj.repr(
# 334 "jc/jc_parser.mly"
    ( _1 )
# 1108 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'primary_expression) in
    Obj.repr(
# 336 "jc/jc_parser.mly"
    ( locate_expr (JCPEapp(_1, [])) )
# 1115 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'primary_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'argument_expression_list) in
    Obj.repr(
# 338 "jc/jc_parser.mly"
    ( locate_expr (JCPEapp(_1, _3)) )
# 1123 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 340 "jc/jc_parser.mly"
    ( locate_expr (JCPEold(_3)) )
# 1130 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 342 "jc/jc_parser.mly"
    ( locate_expr (JCPEoffset_max(_3)) )
# 1137 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 344 "jc/jc_parser.mly"
    ( locate_expr (JCPEoffset_min(_3)) )
# 1144 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 346 "jc/jc_parser.mly"
    ( locate_expr (JCPEderef (_1, _3)) )
# 1152 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    Obj.repr(
# 348 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Upostfix_inc, _1)) )
# 1159 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    Obj.repr(
# 350 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Upostfix_dec, _1)) )
# 1166 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 352 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Uprefix_inc, _2)) )
# 1173 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 354 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Uprefix_dec, _2)) )
# 1180 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 356 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Uplus, _2)) )
# 1187 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 358 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Uminus, _2)) )
# 1194 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 364 "jc/jc_parser.mly"
    ( locate_expr (JCPEunary (Unot, _2)) )
# 1201 "jc/jc_parser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 369 "jc/jc_parser.mly"
    ( [_1] )
# 1208 "jc/jc_parser.ml"
               : 'argument_expression_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'assignment_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'argument_expression_list) in
    Obj.repr(
# 371 "jc/jc_parser.mly"
    ( _1::_3 )
# 1216 "jc/jc_parser.ml"
               : 'argument_expression_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 377 "jc/jc_parser.mly"
    ( _1 )
# 1223 "jc/jc_parser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 379 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bmul, _3)) )
# 1231 "jc/jc_parser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 381 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bdiv, _3)) )
# 1239 "jc/jc_parser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 383 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bmod, _3)) )
# 1247 "jc/jc_parser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 388 "jc/jc_parser.mly"
    ( _1 )
# 1254 "jc/jc_parser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 390 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Badd, _3)) )
# 1262 "jc/jc_parser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 392 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bsub, _3)) )
# 1270 "jc/jc_parser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 397 "jc/jc_parser.mly"
    ( _1 )
# 1277 "jc/jc_parser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 408 "jc/jc_parser.mly"
    ( _1 )
# 1284 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 410 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Blt, _3)) )
# 1292 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 412 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bgt, _3)) )
# 1300 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 414 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Ble, _3)) )
# 1308 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 416 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bge, _3)) )
# 1316 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 418 "jc/jc_parser.mly"
    ( locate_expr (JCPEinstanceof(_1, _3)) )
# 1324 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 420 "jc/jc_parser.mly"
    ( locate_expr (JCPEcast(_1, _3)) )
# 1332 "jc/jc_parser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 425 "jc/jc_parser.mly"
    ( _1 )
# 1339 "jc/jc_parser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 427 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Beq, _3)) )
# 1347 "jc/jc_parser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 429 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary (_1, Bneq, _3)) )
# 1355 "jc/jc_parser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 434 "jc/jc_parser.mly"
    ( _1 )
# 1362 "jc/jc_parser.ml"
               : 'and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'and_expression) in
    Obj.repr(
# 443 "jc/jc_parser.mly"
    ( _1 )
# 1369 "jc/jc_parser.ml"
               : 'exclusive_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'exclusive_or_expression) in
    Obj.repr(
# 452 "jc/jc_parser.mly"
    ( _1 )
# 1376 "jc/jc_parser.ml"
               : 'inclusive_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'inclusive_or_expression) in
    Obj.repr(
# 461 "jc/jc_parser.mly"
    ( _1 )
# 1383 "jc/jc_parser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'inclusive_or_expression) in
    Obj.repr(
# 463 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary(_1, Bland, _3)) )
# 1391 "jc/jc_parser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 468 "jc/jc_parser.mly"
    ( _1 )
# 1398 "jc/jc_parser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 470 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary(_1, Blor, _3)) )
# 1406 "jc/jc_parser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 475 "jc/jc_parser.mly"
    ( _1 )
# 1413 "jc/jc_parser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 477 "jc/jc_parser.mly"
    ( locate_expr (JCPEif (_1, _3, _5)) )
# 1422 "jc/jc_parser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 483 "jc/jc_parser.mly"
    ( _1 )
# 1429 "jc/jc_parser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'assignment_operator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 485 "jc/jc_parser.mly"
    ( let a  =
	match _2 with
		| `Aeq -> JCPEassign (_1, _3)
		| `Aadd -> JCPEassign_op (_1, Badd, _3)
		| `Asub -> JCPEassign_op (_1, Bsub, _3)
		| `Amul -> JCPEassign_op (_1, Bmul, _3)
		| `Adiv -> JCPEassign_op (_1, Bdiv, _3)
		| `Amod -> JCPEassign_op (_1, Bmod, _3)
(*
		| Aleft -> CEassign_op ($1, Bshift_left, $3)
		| Aright -> CEassign_op ($1, Bshift_right, $3)
		| Aand -> CEassign_op ($1, Bbw_and, $3)
		| Axor -> CEassign_op ($1, Bbw_xor, $3)
		| Aor -> CEassign_op ($1, Bbw_or, $3)
*)
      in locate_expr a )
# 1453 "jc/jc_parser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 504 "jc/jc_parser.mly"
     ( `Aeq )
# 1459 "jc/jc_parser.ml"
               : 'assignment_operator))
; (fun __caml_parser_env ->
    Obj.repr(
# 505 "jc/jc_parser.mly"
         ( `Aadd )
# 1465 "jc/jc_parser.ml"
               : 'assignment_operator))
; (fun __caml_parser_env ->
    Obj.repr(
# 506 "jc/jc_parser.mly"
          ( `Asub )
# 1471 "jc/jc_parser.ml"
               : 'assignment_operator))
; (fun __caml_parser_env ->
    Obj.repr(
# 507 "jc/jc_parser.mly"
         ( `Amul )
# 1477 "jc/jc_parser.ml"
               : 'assignment_operator))
; (fun __caml_parser_env ->
    Obj.repr(
# 508 "jc/jc_parser.mly"
          ( `Adiv )
# 1483 "jc/jc_parser.ml"
               : 'assignment_operator))
; (fun __caml_parser_env ->
    Obj.repr(
# 509 "jc/jc_parser.mly"
            ( `Amod )
# 1489 "jc/jc_parser.ml"
               : 'assignment_operator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 522 "jc/jc_parser.mly"
    ( _1 )
# 1496 "jc/jc_parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'type_expr) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'identifier_list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 525 "jc/jc_parser.mly"
    ( locate_expr (JCPEforall(_2,_3,_5)) )
# 1505 "jc/jc_parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 527 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary(_1,Bimplies,_3)) )
# 1513 "jc/jc_parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'expression) in
    Obj.repr(
# 529 "jc/jc_parser.mly"
    ( locate_expr (JCPEbinary(_1,Biff,_3)) )
# 1521 "jc/jc_parser.ml"
               : 'expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 537 "jc/jc_parser.mly"
    ( [_1] )
# 1528 "jc/jc_parser.ml"
               : 'identifier_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'identifier_list) in
    Obj.repr(
# 539 "jc/jc_parser.mly"
    ( _1 :: _3 )
# 1536 "jc/jc_parser.ml"
               : 'identifier_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'type_expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 550 "jc/jc_parser.mly"
    ( locate_statement (JCPSdecl(_1,_2,None)) )
# 1544 "jc/jc_parser.ml"
               : 'declaration))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'type_expr) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 552 "jc/jc_parser.mly"
    ( locate_statement (JCPSdecl(_1,_2,Some _4)) )
# 1553 "jc/jc_parser.ml"
               : 'declaration))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'statement_list) in
    Obj.repr(
# 571 "jc/jc_parser.mly"
     ( _2 )
# 1560 "jc/jc_parser.ml"
               : 'compound_statement))
; (fun __caml_parser_env ->
    Obj.repr(
# 576 "jc/jc_parser.mly"
    ( [] )
# 1566 "jc/jc_parser.ml"
               : 'statement_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'statement) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'statement_list) in
    Obj.repr(
# 578 "jc/jc_parser.mly"
    ( _1 :: _2 )
# 1574 "jc/jc_parser.ml"
               : 'statement_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 584 "jc/jc_parser.mly"
    ( locate_statement JCPSskip )
# 1580 "jc/jc_parser.ml"
               : 'expression_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 589 "jc/jc_parser.mly"
    ( locate_statement (JCPSexpr _1) )
# 1587 "jc/jc_parser.ml"
               : 'expression_statement))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 595 "jc/jc_parser.mly"
    ( let skip = locate_statement JCPSskip in
      locate_statement (JCPSif(_3, _5, skip)) )
# 1596 "jc/jc_parser.ml"
               : 'selection_statement))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'statement) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 598 "jc/jc_parser.mly"
    ( locate_statement (JCPSif (_3, _5, _7)) )
# 1605 "jc/jc_parser.ml"
               : 'selection_statement))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'loop_annot) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 607 "jc/jc_parser.mly"
    ( let (i,v) = _3 in 
      locate_statement (JCPSwhile (_2, i, v, _4)) )
# 1615 "jc/jc_parser.ml"
               : 'iteration_statement))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 627 "jc/jc_parser.mly"
    ( (_2,_5) )
# 1623 "jc/jc_parser.ml"
               : 'loop_annot))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'expression) in
    Obj.repr(
# 637 "jc/jc_parser.mly"
                              ( locate_statement (JCPSreturn _2) )
# 1630 "jc/jc_parser.ml"
               : 'jump_statement))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    Obj.repr(
# 642 "jc/jc_parser.mly"
    ( locate_statement (JCPSpack _3 ) )
# 1637 "jc/jc_parser.ml"
               : 'pack_statement))
; (fun __caml_parser_env ->
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'expression) in
    Obj.repr(
# 644 "jc/jc_parser.mly"
    ( locate_statement (JCPSunpack _3 ) )
# 1644 "jc/jc_parser.ml"
               : 'pack_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'compound_statement) in
    Obj.repr(
# 653 "jc/jc_parser.mly"
    ( locate_statement (JCPSblock _1) )
# 1651 "jc/jc_parser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'expression_statement) in
    Obj.repr(
# 655 "jc/jc_parser.mly"
    ( _1 )
# 1658 "jc/jc_parser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'selection_statement) in
    Obj.repr(
# 657 "jc/jc_parser.mly"
    ( _1 )
# 1665 "jc/jc_parser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'iteration_statement) in
    Obj.repr(
# 659 "jc/jc_parser.mly"
    ( _1 )
# 1672 "jc/jc_parser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'jump_statement) in
    Obj.repr(
# 661 "jc/jc_parser.mly"
    ( _1 )
# 1679 "jc/jc_parser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'declaration) in
    Obj.repr(
# 663 "jc/jc_parser.mly"
    ( _1 )
# 1686 "jc/jc_parser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'pack_statement) in
    Obj.repr(
# 667 "jc/jc_parser.mly"
                 ( _1 )
# 1693 "jc/jc_parser.ml"
               : 'statement))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : Jc_ast.pdecl list)
